protocol

package
v0.0.0-...-94e9374 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 29, 2024 License: BSD-3-Clause Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Space_name = map[int32]string{
		0: "Euclidean",
		1: "Manhattan",
		2: "Cosine",
	}
	Space_value = map[string]int32{
		"Euclidean": 0,
		"Manhattan": 1,
		"Cosine":    2,
	}
)

Enum value maps for Space.

var (
	DatasetManagerChangeType_name = map[int32]string{
		0: "DatasetManagerCreateDataset",
		1: "DatasetManagerDeleteDataset",
		2: "DatasetManagerUpdatePartitionNodes",
	}
	DatasetManagerChangeType_value = map[string]int32{
		"DatasetManagerCreateDataset":        0,
		"DatasetManagerDeleteDataset":        1,
		"DatasetManagerUpdatePartitionNodes": 2,
	}
)

Enum value maps for DatasetManagerChangeType.

var (
	DatasetPartitionNodesChangeType_name = map[int32]string{
		0: "DatasetPartitionNodesChangeAddNode",
		1: "DatasetPartitionNodesChangeRemoveNode",
	}
	DatasetPartitionNodesChangeType_value = map[string]int32{
		"DatasetPartitionNodesChangeAddNode":    0,
		"DatasetPartitionNodesChangeRemoveNode": 1,
	}
)

Enum value maps for DatasetPartitionNodesChangeType.

var (
	PartitionChangeType_name = map[int32]string{
		0: "PartitionChangeInsertValue",
		1: "PartitionChangeUpdateValue",
		2: "PartitionChangeDeleteValue",
		3: "PartitionChangeBatchInsertValue",
		4: "PartitionChangeBatchUpdateValue",
		5: "PartitionChangeBatchDeleteValue",
	}
	PartitionChangeType_value = map[string]int32{
		"PartitionChangeInsertValue":      0,
		"PartitionChangeUpdateValue":      1,
		"PartitionChangeDeleteValue":      2,
		"PartitionChangeBatchInsertValue": 3,
		"PartitionChangeBatchUpdateValue": 4,
		"PartitionChangeBatchDeleteValue": 5,
	}
)

Enum value maps for PartitionChangeType.

var DataManager_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "mindxv.v0.DataManager",
	HandlerType: (*DataManagerServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Insert",
			Handler:    _DataManager_Insert_Handler,
		},
		{
			MethodName: "Update",
			Handler:    _DataManager_Update_Handler,
		},
		{
			MethodName: "Remove",
			Handler:    _DataManager_Remove_Handler,
		},
		{
			MethodName: "BatchInsert",
			Handler:    _DataManager_BatchInsert_Handler,
		},
		{
			MethodName: "BatchUpdate",
			Handler:    _DataManager_BatchUpdate_Handler,
		},
		{
			MethodName: "BatchRemove",
			Handler:    _DataManager_BatchRemove_Handler,
		},
		{
			MethodName: "PartitionBatchInsert",
			Handler:    _DataManager_PartitionBatchInsert_Handler,
		},
		{
			MethodName: "PartitionBatchUpdate",
			Handler:    _DataManager_PartitionBatchUpdate_Handler,
		},
		{
			MethodName: "PartitionBatchRemove",
			Handler:    _DataManager_PartitionBatchRemove_Handler,
		},
		{
			MethodName: "PartitionInfo",
			Handler:    _DataManager_PartitionInfo_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "v0/dataset.proto",
}

DataManager_ServiceDesc is the grpc.ServiceDesc for DataManager service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var DatasetManager_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "mindxv.v0.DatasetManager",
	HandlerType: (*DatasetManagerServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Get",
			Handler:    _DatasetManager_Get_Handler,
		},
		{
			MethodName: "Create",
			Handler:    _DatasetManager_Create_Handler,
		},
		{
			MethodName: "Delete",
			Handler:    _DatasetManager_Delete_Handler,
		},
		{
			MethodName: "GetDatasetSize",
			Handler:    _DatasetManager_GetDatasetSize_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "List",
			Handler:       _DatasetManager_List_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "v0/dataset.proto",
}

DatasetManager_ServiceDesc is the grpc.ServiceDesc for DatasetManager service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_v0_cluster_proto protoreflect.FileDescriptor
var File_v0_core_proto protoreflect.FileDescriptor
var File_v0_dataset_proto protoreflect.FileDescriptor
var File_v0_raft_proto protoreflect.FileDescriptor
var File_v0_search_proto protoreflect.FileDescriptor
var NodesManager_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "mindxv.v0.NodesManager",
	HandlerType: (*NodesManagerServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "RemoveNode",
			Handler:    _NodesManager_RemoveNode_Handler,
		},
		{
			MethodName: "LoadInfo",
			Handler:    _NodesManager_LoadInfo_Handler,
		},
	},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "ListNodes",
			Handler:       _NodesManager_ListNodes_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "AddNode",
			Handler:       _NodesManager_AddNode_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "v0/cluster.proto",
}

NodesManager_ServiceDesc is the grpc.ServiceDesc for NodesManager service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var RaftTransport_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "mindxv.v0.RaftTransport",
	HandlerType: (*RaftTransportServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "Receive",
			Handler:    _RaftTransport_Receive_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "v0/raft.proto",
}

RaftTransport_ServiceDesc is the grpc.ServiceDesc for RaftTransport service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var Search_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "mindxv.v0.Search",
	HandlerType: (*SearchServer)(nil),
	Methods:     []grpc.MethodDesc{},
	Streams: []grpc.StreamDesc{
		{
			StreamName:    "Search",
			Handler:       _Search_Search_Handler,
			ServerStreams: true,
		},
		{
			StreamName:    "SearchPartitions",
			Handler:       _Search_SearchPartitions_Handler,
			ServerStreams: true,
		},
	},
	Metadata: "v0/search.proto",
}

Search_ServiceDesc is the grpc.ServiceDesc for Search service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

Functions

func RegisterDataManagerServer

func RegisterDataManagerServer(s grpc.ServiceRegistrar, srv DataManagerServer)

func RegisterDatasetManagerServer

func RegisterDatasetManagerServer(s grpc.ServiceRegistrar, srv DatasetManagerServer)

func RegisterNodesManagerServer

func RegisterNodesManagerServer(s grpc.ServiceRegistrar, srv NodesManagerServer)

func RegisterRaftTransportServer

func RegisterRaftTransportServer(s grpc.ServiceRegistrar, srv RaftTransportServer)

func RegisterSearchServer

func RegisterSearchServer(s grpc.ServiceRegistrar, srv SearchServer)

Types

type BatchItem

type BatchItem struct {
	Id       []byte            `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Value    []float32         `protobuf:"fixed32,2,rep,packed,name=value,proto3" json:"value,omitempty"`
	Metadata map[string]string `` /* 157-byte string literal not displayed */
	Level    int32             `protobuf:"varint,4,opt,name=level,proto3" json:"level,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchItem) Descriptor deprecated

func (*BatchItem) Descriptor() ([]byte, []int)

Deprecated: Use BatchItem.ProtoReflect.Descriptor instead.

func (*BatchItem) GetId

func (x *BatchItem) GetId() []byte

func (*BatchItem) GetLevel

func (x *BatchItem) GetLevel() int32

func (*BatchItem) GetMetadata

func (x *BatchItem) GetMetadata() map[string]string

func (*BatchItem) GetValue

func (x *BatchItem) GetValue() []float32

func (*BatchItem) ProtoMessage

func (*BatchItem) ProtoMessage()

func (*BatchItem) ProtoReflect

func (x *BatchItem) ProtoReflect() protoreflect.Message

func (*BatchItem) Reset

func (x *BatchItem) Reset()

func (*BatchItem) String

func (x *BatchItem) String() string

type BatchRequest

type BatchRequest struct {
	DatasetId []byte       `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	Items     []*BatchItem `protobuf:"bytes,2,rep,name=items,proto3" json:"items,omitempty"`
	// contains filtered or unexported fields
}

func (*BatchRequest) Descriptor deprecated

func (*BatchRequest) Descriptor() ([]byte, []int)

Deprecated: Use BatchRequest.ProtoReflect.Descriptor instead.

func (*BatchRequest) GetDatasetId

func (x *BatchRequest) GetDatasetId() []byte

func (*BatchRequest) GetItems

func (x *BatchRequest) GetItems() []*BatchItem

func (*BatchRequest) ProtoMessage

func (*BatchRequest) ProtoMessage()

func (*BatchRequest) ProtoReflect

func (x *BatchRequest) ProtoReflect() protoreflect.Message

func (*BatchRequest) Reset

func (x *BatchRequest) Reset()

func (*BatchRequest) String

func (x *BatchRequest) String() string

type BatchResponse

type BatchResponse struct {
	Errors map[string]string `` /* 153-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*BatchResponse) Descriptor deprecated

func (*BatchResponse) Descriptor() ([]byte, []int)

Deprecated: Use BatchResponse.ProtoReflect.Descriptor instead.

func (*BatchResponse) GetErrors

func (x *BatchResponse) GetErrors() map[string]string

func (*BatchResponse) ProtoMessage

func (*BatchResponse) ProtoMessage()

func (*BatchResponse) ProtoReflect

func (x *BatchResponse) ProtoReflect() protoreflect.Message

func (*BatchResponse) Reset

func (x *BatchResponse) Reset()

func (*BatchResponse) String

func (x *BatchResponse) String() string

type DataManagerClient

type DataManagerClient interface {
	Insert(ctx context.Context, in *InsertRequest, opts ...grpc.CallOption) (*EmptyMessage, error)
	Update(ctx context.Context, in *UpdateRequest, opts ...grpc.CallOption) (*EmptyMessage, error)
	Remove(ctx context.Context, in *RemoveRequest, opts ...grpc.CallOption) (*EmptyMessage, error)
	BatchInsert(ctx context.Context, in *BatchRequest, opts ...grpc.CallOption) (*BatchResponse, error)
	BatchUpdate(ctx context.Context, in *BatchRequest, opts ...grpc.CallOption) (*BatchResponse, error)
	BatchRemove(ctx context.Context, in *BatchRequest, opts ...grpc.CallOption) (*BatchResponse, error)
	PartitionBatchInsert(ctx context.Context, in *PartitionBatchRequest, opts ...grpc.CallOption) (*BatchResponse, error)
	PartitionBatchUpdate(ctx context.Context, in *PartitionBatchRequest, opts ...grpc.CallOption) (*BatchResponse, error)
	PartitionBatchRemove(ctx context.Context, in *PartitionBatchRequest, opts ...grpc.CallOption) (*BatchResponse, error)
	PartitionInfo(ctx context.Context, in *PartitionInfoRequest, opts ...grpc.CallOption) (*PartitionInfoResponse, error)
}

DataManagerClient is the client API for DataManager service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type DataManagerServer

DataManagerServer is the server API for DataManager service. All implementations should embed UnimplementedDataManagerServer for forward compatibility

type Dataset

type Dataset struct {
	Id                []byte       `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Dimension         uint32       `protobuf:"varint,2,opt,name=dimension,proto3" json:"dimension,omitempty"`
	Space             Space        `protobuf:"varint,3,opt,name=space,proto3,enum=mindxv.v0.Space" json:"space,omitempty"`
	PartitionCount    uint32       `protobuf:"varint,4,opt,name=partition_count,json=partitionCount,proto3" json:"partition_count,omitempty"`
	ReplicationFactor uint32       `protobuf:"varint,5,opt,name=replication_factor,json=replicationFactor,proto3" json:"replication_factor,omitempty"`
	Partitions        []*Partition `protobuf:"bytes,6,rep,name=partitions,proto3" json:"partitions,omitempty"`
	Size              uint64       `protobuf:"varint,7,opt,name=size,proto3" json:"size,omitempty"`
	// contains filtered or unexported fields
}

func (*Dataset) Descriptor deprecated

func (*Dataset) Descriptor() ([]byte, []int)

Deprecated: Use Dataset.ProtoReflect.Descriptor instead.

func (*Dataset) GetDimension

func (x *Dataset) GetDimension() uint32

func (*Dataset) GetId

func (x *Dataset) GetId() []byte

func (*Dataset) GetPartitionCount

func (x *Dataset) GetPartitionCount() uint32

func (*Dataset) GetPartitions

func (x *Dataset) GetPartitions() []*Partition

func (*Dataset) GetReplicationFactor

func (x *Dataset) GetReplicationFactor() uint32

func (*Dataset) GetSize

func (x *Dataset) GetSize() uint64

func (*Dataset) GetSpace

func (x *Dataset) GetSpace() Space

func (*Dataset) ProtoMessage

func (*Dataset) ProtoMessage()

func (*Dataset) ProtoReflect

func (x *Dataset) ProtoReflect() protoreflect.Message

func (*Dataset) Reset

func (x *Dataset) Reset()

func (*Dataset) String

func (x *Dataset) String() string

type DatasetManagerChange

type DatasetManagerChange struct {
	Type           DatasetManagerChangeType `protobuf:"varint,1,opt,name=type,proto3,enum=mindxv.v0.DatasetManagerChangeType" json:"type,omitempty"`
	NotificationId []byte                   `protobuf:"bytes,2,opt,name=notification_id,json=notificationId,proto3" json:"notification_id,omitempty"`
	Data           []byte                   `protobuf:"bytes,3,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

func (*DatasetManagerChange) Descriptor deprecated

func (*DatasetManagerChange) Descriptor() ([]byte, []int)

Deprecated: Use DatasetManagerChange.ProtoReflect.Descriptor instead.

func (*DatasetManagerChange) GetData

func (x *DatasetManagerChange) GetData() []byte

func (*DatasetManagerChange) GetNotificationId

func (x *DatasetManagerChange) GetNotificationId() []byte

func (*DatasetManagerChange) GetType

func (*DatasetManagerChange) ProtoMessage

func (*DatasetManagerChange) ProtoMessage()

func (*DatasetManagerChange) ProtoReflect

func (x *DatasetManagerChange) ProtoReflect() protoreflect.Message

func (*DatasetManagerChange) Reset

func (x *DatasetManagerChange) Reset()

func (*DatasetManagerChange) String

func (x *DatasetManagerChange) String() string

type DatasetManagerChangeType

type DatasetManagerChangeType int32
const (
	DatasetManagerChangeType_DatasetManagerCreateDataset        DatasetManagerChangeType = 0
	DatasetManagerChangeType_DatasetManagerDeleteDataset        DatasetManagerChangeType = 1
	DatasetManagerChangeType_DatasetManagerUpdatePartitionNodes DatasetManagerChangeType = 2
)

func (DatasetManagerChangeType) Descriptor

func (DatasetManagerChangeType) Enum

func (DatasetManagerChangeType) EnumDescriptor deprecated

func (DatasetManagerChangeType) EnumDescriptor() ([]byte, []int)

Deprecated: Use DatasetManagerChangeType.Descriptor instead.

func (DatasetManagerChangeType) Number

func (DatasetManagerChangeType) String

func (x DatasetManagerChangeType) String() string

func (DatasetManagerChangeType) Type

type DatasetManagerClient

type DatasetManagerClient interface {
	List(ctx context.Context, in *ListDatasetsRequest, opts ...grpc.CallOption) (DatasetManager_ListClient, error)
	Get(ctx context.Context, in *GetDatasetRequest, opts ...grpc.CallOption) (*Dataset, error)
	Create(ctx context.Context, in *Dataset, opts ...grpc.CallOption) (*Dataset, error)
	Delete(ctx context.Context, in *UUIDRequest, opts ...grpc.CallOption) (*EmptyMessage, error)
	GetDatasetSize(ctx context.Context, in *GetDatasetRequest, opts ...grpc.CallOption) (*DatasetSize, error)
}

DatasetManagerClient is the client API for DatasetManager service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type DatasetManagerServer

DatasetManagerServer is the server API for DatasetManager service. All implementations should embed UnimplementedDatasetManagerServer for forward compatibility

type DatasetManagerSnapshot

type DatasetManagerSnapshot struct {
	Datasets []*Dataset `protobuf:"bytes,1,rep,name=datasets,proto3" json:"datasets,omitempty"`
	// contains filtered or unexported fields
}

func (*DatasetManagerSnapshot) Descriptor deprecated

func (*DatasetManagerSnapshot) Descriptor() ([]byte, []int)

Deprecated: Use DatasetManagerSnapshot.ProtoReflect.Descriptor instead.

func (*DatasetManagerSnapshot) GetDatasets

func (x *DatasetManagerSnapshot) GetDatasets() []*Dataset

func (*DatasetManagerSnapshot) ProtoMessage

func (*DatasetManagerSnapshot) ProtoMessage()

func (*DatasetManagerSnapshot) ProtoReflect

func (x *DatasetManagerSnapshot) ProtoReflect() protoreflect.Message

func (*DatasetManagerSnapshot) Reset

func (x *DatasetManagerSnapshot) Reset()

func (*DatasetManagerSnapshot) String

func (x *DatasetManagerSnapshot) String() string

type DatasetManager_ListClient

type DatasetManager_ListClient interface {
	Recv() (*Dataset, error)
	grpc.ClientStream
}

type DatasetManager_ListServer

type DatasetManager_ListServer interface {
	Send(*Dataset) error
	grpc.ServerStream
}

type DatasetPartitionNodesChange

type DatasetPartitionNodesChange struct {
	Type        DatasetPartitionNodesChangeType `protobuf:"varint,1,opt,name=type,proto3,enum=mindxv.v0.DatasetPartitionNodesChangeType" json:"type,omitempty"`
	DatasetId   []byte                          `protobuf:"bytes,2,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	PartitionId []byte                          `protobuf:"bytes,3,opt,name=partition_id,json=partitionId,proto3" json:"partition_id,omitempty"`
	NodeId      uint64                          `protobuf:"varint,4,opt,name=node_id,json=nodeId,proto3" json:"node_id,omitempty"`
	// contains filtered or unexported fields
}

func (*DatasetPartitionNodesChange) Descriptor deprecated

func (*DatasetPartitionNodesChange) Descriptor() ([]byte, []int)

Deprecated: Use DatasetPartitionNodesChange.ProtoReflect.Descriptor instead.

func (*DatasetPartitionNodesChange) GetDatasetId

func (x *DatasetPartitionNodesChange) GetDatasetId() []byte

func (*DatasetPartitionNodesChange) GetNodeId

func (x *DatasetPartitionNodesChange) GetNodeId() uint64

func (*DatasetPartitionNodesChange) GetPartitionId

func (x *DatasetPartitionNodesChange) GetPartitionId() []byte

func (*DatasetPartitionNodesChange) GetType

func (*DatasetPartitionNodesChange) ProtoMessage

func (*DatasetPartitionNodesChange) ProtoMessage()

func (*DatasetPartitionNodesChange) ProtoReflect

func (*DatasetPartitionNodesChange) Reset

func (x *DatasetPartitionNodesChange) Reset()

func (*DatasetPartitionNodesChange) String

func (x *DatasetPartitionNodesChange) String() string

type DatasetPartitionNodesChangeType

type DatasetPartitionNodesChangeType int32
const (
	DatasetPartitionNodesChangeType_DatasetPartitionNodesChangeAddNode    DatasetPartitionNodesChangeType = 0
	DatasetPartitionNodesChangeType_DatasetPartitionNodesChangeRemoveNode DatasetPartitionNodesChangeType = 1
)

func (DatasetPartitionNodesChangeType) Descriptor

func (DatasetPartitionNodesChangeType) Enum

func (DatasetPartitionNodesChangeType) EnumDescriptor deprecated

func (DatasetPartitionNodesChangeType) EnumDescriptor() ([]byte, []int)

Deprecated: Use DatasetPartitionNodesChangeType.Descriptor instead.

func (DatasetPartitionNodesChangeType) Number

func (DatasetPartitionNodesChangeType) String

func (DatasetPartitionNodesChangeType) Type

type DatasetSize

type DatasetSize struct {
	Len       uint64 `protobuf:"varint,1,opt,name=len,proto3" json:"len,omitempty"`
	BytesSize uint64 `protobuf:"varint,2,opt,name=bytes_size,json=bytesSize,proto3" json:"bytes_size,omitempty"`
	// contains filtered or unexported fields
}

func (*DatasetSize) Descriptor deprecated

func (*DatasetSize) Descriptor() ([]byte, []int)

Deprecated: Use DatasetSize.ProtoReflect.Descriptor instead.

func (*DatasetSize) GetBytesSize

func (x *DatasetSize) GetBytesSize() uint64

func (*DatasetSize) GetLen

func (x *DatasetSize) GetLen() uint64

func (*DatasetSize) ProtoMessage

func (*DatasetSize) ProtoMessage()

func (*DatasetSize) ProtoReflect

func (x *DatasetSize) ProtoReflect() protoreflect.Message

func (*DatasetSize) Reset

func (x *DatasetSize) Reset()

func (*DatasetSize) String

func (x *DatasetSize) String() string

type EmptyMessage

type EmptyMessage struct {
	// contains filtered or unexported fields
}

func (*EmptyMessage) Descriptor deprecated

func (*EmptyMessage) Descriptor() ([]byte, []int)

Deprecated: Use EmptyMessage.ProtoReflect.Descriptor instead.

func (*EmptyMessage) ProtoMessage

func (*EmptyMessage) ProtoMessage()

func (*EmptyMessage) ProtoReflect

func (x *EmptyMessage) ProtoReflect() protoreflect.Message

func (*EmptyMessage) Reset

func (x *EmptyMessage) Reset()

func (*EmptyMessage) String

func (x *EmptyMessage) String() string

type GetDatasetRequest

type GetDatasetRequest struct {
	DatasetId []byte `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	WithSize  bool   `protobuf:"varint,2,opt,name=with_size,json=withSize,proto3" json:"with_size,omitempty"`
	// contains filtered or unexported fields
}

func (*GetDatasetRequest) Descriptor deprecated

func (*GetDatasetRequest) Descriptor() ([]byte, []int)

Deprecated: Use GetDatasetRequest.ProtoReflect.Descriptor instead.

func (*GetDatasetRequest) GetDatasetId

func (x *GetDatasetRequest) GetDatasetId() []byte

func (*GetDatasetRequest) GetWithSize

func (x *GetDatasetRequest) GetWithSize() bool

func (*GetDatasetRequest) ProtoMessage

func (*GetDatasetRequest) ProtoMessage()

func (*GetDatasetRequest) ProtoReflect

func (x *GetDatasetRequest) ProtoReflect() protoreflect.Message

func (*GetDatasetRequest) Reset

func (x *GetDatasetRequest) Reset()

func (*GetDatasetRequest) String

func (x *GetDatasetRequest) String() string

type InsertRequest

type InsertRequest struct {
	DatasetId []byte            `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	Id        []byte            `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	Value     []float32         `protobuf:"fixed32,3,rep,packed,name=value,proto3" json:"value,omitempty"`
	Metadata  map[string]string `` /* 157-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*InsertRequest) Descriptor deprecated

func (*InsertRequest) Descriptor() ([]byte, []int)

Deprecated: Use InsertRequest.ProtoReflect.Descriptor instead.

func (*InsertRequest) GetDatasetId

func (x *InsertRequest) GetDatasetId() []byte

func (*InsertRequest) GetId

func (x *InsertRequest) GetId() []byte

func (*InsertRequest) GetMetadata

func (x *InsertRequest) GetMetadata() map[string]string

func (*InsertRequest) GetValue

func (x *InsertRequest) GetValue() []float32

func (*InsertRequest) ProtoMessage

func (*InsertRequest) ProtoMessage()

func (*InsertRequest) ProtoReflect

func (x *InsertRequest) ProtoReflect() protoreflect.Message

func (*InsertRequest) Reset

func (x *InsertRequest) Reset()

func (*InsertRequest) String

func (x *InsertRequest) String() string

type ListDatasetsRequest

type ListDatasetsRequest struct {
	WithSize bool `protobuf:"varint,1,opt,name=with_size,json=withSize,proto3" json:"with_size,omitempty"`
	// contains filtered or unexported fields
}

func (*ListDatasetsRequest) Descriptor deprecated

func (*ListDatasetsRequest) Descriptor() ([]byte, []int)

Deprecated: Use ListDatasetsRequest.ProtoReflect.Descriptor instead.

func (*ListDatasetsRequest) GetWithSize

func (x *ListDatasetsRequest) GetWithSize() bool

func (*ListDatasetsRequest) ProtoMessage

func (*ListDatasetsRequest) ProtoMessage()

func (*ListDatasetsRequest) ProtoReflect

func (x *ListDatasetsRequest) ProtoReflect() protoreflect.Message

func (*ListDatasetsRequest) Reset

func (x *ListDatasetsRequest) Reset()

func (*ListDatasetsRequest) String

func (x *ListDatasetsRequest) String() string

type Node

type Node struct {
	Id      uint64 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
	Address string `protobuf:"bytes,2,opt,name=address,proto3" json:"address,omitempty"`
	// contains filtered or unexported fields
}

func (*Node) Descriptor deprecated

func (*Node) Descriptor() ([]byte, []int)

Deprecated: Use Node.ProtoReflect.Descriptor instead.

func (*Node) GetAddress

func (x *Node) GetAddress() string

func (*Node) GetId

func (x *Node) GetId() uint64

func (*Node) ProtoMessage

func (*Node) ProtoMessage()

func (*Node) ProtoReflect

func (x *Node) ProtoReflect() protoreflect.Message

func (*Node) Reset

func (x *Node) Reset()

func (*Node) String

func (x *Node) String() string

type NodeLoadInfo

type NodeLoadInfo struct {
	Uptime         uint64  `protobuf:"varint,1,opt,name=uptime,proto3" json:"uptime,omitempty"`
	CpuLoad1       float64 `protobuf:"fixed64,2,opt,name=cpu_load1,json=cpuLoad1,proto3" json:"cpu_load1,omitempty"`
	CpuLoad5       float64 `protobuf:"fixed64,3,opt,name=cpu_load5,json=cpuLoad5,proto3" json:"cpu_load5,omitempty"`
	CpuLoad15      float64 `protobuf:"fixed64,4,opt,name=cpu_load15,json=cpuLoad15,proto3" json:"cpu_load15,omitempty"`
	MemTotal       uint64  `protobuf:"varint,5,opt,name=mem_total,json=memTotal,proto3" json:"mem_total,omitempty"`
	MemAvailable   uint64  `protobuf:"varint,6,opt,name=mem_available,json=memAvailable,proto3" json:"mem_available,omitempty"`
	MemUsed        uint64  `protobuf:"varint,7,opt,name=mem_used,json=memUsed,proto3" json:"mem_used,omitempty"`
	MemFree        uint64  `protobuf:"varint,8,opt,name=mem_free,json=memFree,proto3" json:"mem_free,omitempty"`
	MemUsedPercent float64 `protobuf:"fixed64,9,opt,name=mem_used_percent,json=memUsedPercent,proto3" json:"mem_used_percent,omitempty"`
	// contains filtered or unexported fields
}

func (*NodeLoadInfo) Descriptor deprecated

func (*NodeLoadInfo) Descriptor() ([]byte, []int)

Deprecated: Use NodeLoadInfo.ProtoReflect.Descriptor instead.

func (*NodeLoadInfo) GetCpuLoad1

func (x *NodeLoadInfo) GetCpuLoad1() float64

func (*NodeLoadInfo) GetCpuLoad15

func (x *NodeLoadInfo) GetCpuLoad15() float64

func (*NodeLoadInfo) GetCpuLoad5

func (x *NodeLoadInfo) GetCpuLoad5() float64

func (*NodeLoadInfo) GetMemAvailable

func (x *NodeLoadInfo) GetMemAvailable() uint64

func (*NodeLoadInfo) GetMemFree

func (x *NodeLoadInfo) GetMemFree() uint64

func (*NodeLoadInfo) GetMemTotal

func (x *NodeLoadInfo) GetMemTotal() uint64

func (*NodeLoadInfo) GetMemUsed

func (x *NodeLoadInfo) GetMemUsed() uint64

func (*NodeLoadInfo) GetMemUsedPercent

func (x *NodeLoadInfo) GetMemUsedPercent() float64

func (*NodeLoadInfo) GetUptime

func (x *NodeLoadInfo) GetUptime() uint64

func (*NodeLoadInfo) ProtoMessage

func (*NodeLoadInfo) ProtoMessage()

func (*NodeLoadInfo) ProtoReflect

func (x *NodeLoadInfo) ProtoReflect() protoreflect.Message

func (*NodeLoadInfo) Reset

func (x *NodeLoadInfo) Reset()

func (*NodeLoadInfo) String

func (x *NodeLoadInfo) String() string

type NodesManagerClient

type NodesManagerClient interface {
	ListNodes(ctx context.Context, in *EmptyMessage, opts ...grpc.CallOption) (NodesManager_ListNodesClient, error)
	AddNode(ctx context.Context, in *Node, opts ...grpc.CallOption) (NodesManager_AddNodeClient, error)
	RemoveNode(ctx context.Context, in *Node, opts ...grpc.CallOption) (*EmptyMessage, error)
	LoadInfo(ctx context.Context, in *EmptyMessage, opts ...grpc.CallOption) (*NodeLoadInfo, error)
}

NodesManagerClient is the client API for NodesManager service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type NodesManagerServer

type NodesManagerServer interface {
	ListNodes(*EmptyMessage, NodesManager_ListNodesServer) error
	AddNode(*Node, NodesManager_AddNodeServer) error
	RemoveNode(context.Context, *Node) (*EmptyMessage, error)
	LoadInfo(context.Context, *EmptyMessage) (*NodeLoadInfo, error)
}

NodesManagerServer is the server API for NodesManager service. All implementations should embed UnimplementedNodesManagerServer for forward compatibility

type NodesManager_AddNodeClient

type NodesManager_AddNodeClient interface {
	Recv() (*Node, error)
	grpc.ClientStream
}

type NodesManager_AddNodeServer

type NodesManager_AddNodeServer interface {
	Send(*Node) error
	grpc.ServerStream
}

type NodesManager_ListNodesClient

type NodesManager_ListNodesClient interface {
	Recv() (*Node, error)
	grpc.ClientStream
}

type NodesManager_ListNodesServer

type NodesManager_ListNodesServer interface {
	Send(*Node) error
	grpc.ServerStream
}

type Partition

type Partition struct {
	Id      []byte   `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	NodeIds []uint64 `protobuf:"varint,2,rep,packed,name=node_ids,json=nodeIds,proto3" json:"node_ids,omitempty"`
	// contains filtered or unexported fields
}

func (*Partition) Descriptor deprecated

func (*Partition) Descriptor() ([]byte, []int)

Deprecated: Use Partition.ProtoReflect.Descriptor instead.

func (*Partition) GetId

func (x *Partition) GetId() []byte

func (*Partition) GetNodeIds

func (x *Partition) GetNodeIds() []uint64

func (*Partition) ProtoMessage

func (*Partition) ProtoMessage()

func (*Partition) ProtoReflect

func (x *Partition) ProtoReflect() protoreflect.Message

func (*Partition) Reset

func (x *Partition) Reset()

func (*Partition) String

func (x *Partition) String() string

type PartitionBatchRequest

type PartitionBatchRequest struct {
	DatasetId   []byte       `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	PartitionId []byte       `protobuf:"bytes,2,opt,name=partition_id,json=partitionId,proto3" json:"partition_id,omitempty"`
	Items       []*BatchItem `protobuf:"bytes,3,rep,name=items,proto3" json:"items,omitempty"`
	// contains filtered or unexported fields
}

func (*PartitionBatchRequest) Descriptor deprecated

func (*PartitionBatchRequest) Descriptor() ([]byte, []int)

Deprecated: Use PartitionBatchRequest.ProtoReflect.Descriptor instead.

func (*PartitionBatchRequest) GetDatasetId

func (x *PartitionBatchRequest) GetDatasetId() []byte

func (*PartitionBatchRequest) GetItems

func (x *PartitionBatchRequest) GetItems() []*BatchItem

func (*PartitionBatchRequest) GetPartitionId

func (x *PartitionBatchRequest) GetPartitionId() []byte

func (*PartitionBatchRequest) ProtoMessage

func (*PartitionBatchRequest) ProtoMessage()

func (*PartitionBatchRequest) ProtoReflect

func (x *PartitionBatchRequest) ProtoReflect() protoreflect.Message

func (*PartitionBatchRequest) Reset

func (x *PartitionBatchRequest) Reset()

func (*PartitionBatchRequest) String

func (x *PartitionBatchRequest) String() string

type PartitionChange

type PartitionChange struct {
	Type           PartitionChangeType `protobuf:"varint,1,opt,name=type,proto3,enum=mindxv.v0.PartitionChangeType" json:"type,omitempty"`
	NotificationId []byte              `protobuf:"bytes,2,opt,name=notification_id,json=notificationId,proto3" json:"notification_id,omitempty"`
	Id             []byte              `protobuf:"bytes,3,opt,name=id,proto3" json:"id,omitempty"`
	Value          []float32           `protobuf:"fixed32,4,rep,packed,name=value,proto3" json:"value,omitempty"`
	Metadata       map[string]string   `` /* 157-byte string literal not displayed */
	Level          int32               `protobuf:"varint,6,opt,name=level,proto3" json:"level,omitempty"`
	BatchItems     []*BatchItem        `protobuf:"bytes,7,rep,name=batch_items,json=batchItems,proto3" json:"batch_items,omitempty"`
	// contains filtered or unexported fields
}

func (*PartitionChange) Descriptor deprecated

func (*PartitionChange) Descriptor() ([]byte, []int)

Deprecated: Use PartitionChange.ProtoReflect.Descriptor instead.

func (*PartitionChange) GetBatchItems

func (x *PartitionChange) GetBatchItems() []*BatchItem

func (*PartitionChange) GetId

func (x *PartitionChange) GetId() []byte

func (*PartitionChange) GetLevel

func (x *PartitionChange) GetLevel() int32

func (*PartitionChange) GetMetadata

func (x *PartitionChange) GetMetadata() map[string]string

func (*PartitionChange) GetNotificationId

func (x *PartitionChange) GetNotificationId() []byte

func (*PartitionChange) GetType

func (x *PartitionChange) GetType() PartitionChangeType

func (*PartitionChange) GetValue

func (x *PartitionChange) GetValue() []float32

func (*PartitionChange) ProtoMessage

func (*PartitionChange) ProtoMessage()

func (*PartitionChange) ProtoReflect

func (x *PartitionChange) ProtoReflect() protoreflect.Message

func (*PartitionChange) Reset

func (x *PartitionChange) Reset()

func (*PartitionChange) String

func (x *PartitionChange) String() string

type PartitionChangeType

type PartitionChangeType int32
const (
	PartitionChangeType_PartitionChangeInsertValue      PartitionChangeType = 0
	PartitionChangeType_PartitionChangeUpdateValue      PartitionChangeType = 1
	PartitionChangeType_PartitionChangeDeleteValue      PartitionChangeType = 2
	PartitionChangeType_PartitionChangeBatchInsertValue PartitionChangeType = 3
	PartitionChangeType_PartitionChangeBatchUpdateValue PartitionChangeType = 4
	PartitionChangeType_PartitionChangeBatchDeleteValue PartitionChangeType = 5
)

func (PartitionChangeType) Descriptor

func (PartitionChangeType) Enum

func (PartitionChangeType) EnumDescriptor deprecated

func (PartitionChangeType) EnumDescriptor() ([]byte, []int)

Deprecated: Use PartitionChangeType.Descriptor instead.

func (PartitionChangeType) Number

func (PartitionChangeType) String

func (x PartitionChangeType) String() string

func (PartitionChangeType) Type

type PartitionInfoRequest

type PartitionInfoRequest struct {
	DatasetId   []byte `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	PartitionId []byte `protobuf:"bytes,2,opt,name=partition_id,json=partitionId,proto3" json:"partition_id,omitempty"`
	// contains filtered or unexported fields
}

func (*PartitionInfoRequest) Descriptor deprecated

func (*PartitionInfoRequest) Descriptor() ([]byte, []int)

Deprecated: Use PartitionInfoRequest.ProtoReflect.Descriptor instead.

func (*PartitionInfoRequest) GetDatasetId

func (x *PartitionInfoRequest) GetDatasetId() []byte

func (*PartitionInfoRequest) GetPartitionId

func (x *PartitionInfoRequest) GetPartitionId() []byte

func (*PartitionInfoRequest) ProtoMessage

func (*PartitionInfoRequest) ProtoMessage()

func (*PartitionInfoRequest) ProtoReflect

func (x *PartitionInfoRequest) ProtoReflect() protoreflect.Message

func (*PartitionInfoRequest) Reset

func (x *PartitionInfoRequest) Reset()

func (*PartitionInfoRequest) String

func (x *PartitionInfoRequest) String() string

type PartitionInfoResponse

type PartitionInfoResponse struct {
	Len       uint64 `protobuf:"varint,1,opt,name=len,proto3" json:"len,omitempty"`
	BytesSize uint64 `protobuf:"varint,2,opt,name=bytes_size,json=bytesSize,proto3" json:"bytes_size,omitempty"`
	// contains filtered or unexported fields
}

func (*PartitionInfoResponse) Descriptor deprecated

func (*PartitionInfoResponse) Descriptor() ([]byte, []int)

Deprecated: Use PartitionInfoResponse.ProtoReflect.Descriptor instead.

func (*PartitionInfoResponse) GetBytesSize

func (x *PartitionInfoResponse) GetBytesSize() uint64

func (*PartitionInfoResponse) GetLen

func (x *PartitionInfoResponse) GetLen() uint64

func (*PartitionInfoResponse) ProtoMessage

func (*PartitionInfoResponse) ProtoMessage()

func (*PartitionInfoResponse) ProtoReflect

func (x *PartitionInfoResponse) ProtoReflect() protoreflect.Message

func (*PartitionInfoResponse) Reset

func (x *PartitionInfoResponse) Reset()

func (*PartitionInfoResponse) String

func (x *PartitionInfoResponse) String() string

type RaftMessage

type RaftMessage struct {
	GroupId []byte `protobuf:"bytes,1,opt,name=group_id,json=groupId,proto3" json:"group_id,omitempty"`
	Message []byte `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	// contains filtered or unexported fields
}

func (*RaftMessage) Descriptor deprecated

func (*RaftMessage) Descriptor() ([]byte, []int)

Deprecated: Use RaftMessage.ProtoReflect.Descriptor instead.

func (*RaftMessage) GetGroupId

func (x *RaftMessage) GetGroupId() []byte

func (*RaftMessage) GetMessage

func (x *RaftMessage) GetMessage() []byte

func (*RaftMessage) ProtoMessage

func (*RaftMessage) ProtoMessage()

func (*RaftMessage) ProtoReflect

func (x *RaftMessage) ProtoReflect() protoreflect.Message

func (*RaftMessage) Reset

func (x *RaftMessage) Reset()

func (*RaftMessage) String

func (x *RaftMessage) String() string

type RaftTransportClient

type RaftTransportClient interface {
	Receive(ctx context.Context, in *RaftMessage, opts ...grpc.CallOption) (*EmptyMessage, error)
}

RaftTransportClient is the client API for RaftTransport service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type RaftTransportServer

type RaftTransportServer interface {
	Receive(context.Context, *RaftMessage) (*EmptyMessage, error)
}

RaftTransportServer is the server API for RaftTransport service. All implementations should embed UnimplementedRaftTransportServer for forward compatibility

type RemoveRequest

type RemoveRequest struct {
	DatasetId []byte `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	Id        []byte `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*RemoveRequest) Descriptor deprecated

func (*RemoveRequest) Descriptor() ([]byte, []int)

Deprecated: Use RemoveRequest.ProtoReflect.Descriptor instead.

func (*RemoveRequest) GetDatasetId

func (x *RemoveRequest) GetDatasetId() []byte

func (*RemoveRequest) GetId

func (x *RemoveRequest) GetId() []byte

func (*RemoveRequest) ProtoMessage

func (*RemoveRequest) ProtoMessage()

func (*RemoveRequest) ProtoReflect

func (x *RemoveRequest) ProtoReflect() protoreflect.Message

func (*RemoveRequest) Reset

func (x *RemoveRequest) Reset()

func (*RemoveRequest) String

func (x *RemoveRequest) String() string

type SearchClient

type SearchClient interface {
	Search(ctx context.Context, in *SearchRequest, opts ...grpc.CallOption) (Search_SearchClient, error)
	SearchPartitions(ctx context.Context, in *SearchPartitionsRequest, opts ...grpc.CallOption) (Search_SearchPartitionsClient, error)
}

SearchClient is the client API for Search service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

func NewSearchClient

func NewSearchClient(cc grpc.ClientConnInterface) SearchClient

type SearchPartitionsRequest

type SearchPartitionsRequest struct {
	DatasetId    []byte    `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	PartitionIds [][]byte  `protobuf:"bytes,2,rep,name=partition_ids,json=partitionIds,proto3" json:"partition_ids,omitempty"`
	Query        []float32 `protobuf:"fixed32,3,rep,packed,name=query,proto3" json:"query,omitempty"`
	K            uint32    `protobuf:"varint,4,opt,name=k,proto3" json:"k,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchPartitionsRequest) Descriptor deprecated

func (*SearchPartitionsRequest) Descriptor() ([]byte, []int)

Deprecated: Use SearchPartitionsRequest.ProtoReflect.Descriptor instead.

func (*SearchPartitionsRequest) GetDatasetId

func (x *SearchPartitionsRequest) GetDatasetId() []byte

func (*SearchPartitionsRequest) GetK

func (x *SearchPartitionsRequest) GetK() uint32

func (*SearchPartitionsRequest) GetPartitionIds

func (x *SearchPartitionsRequest) GetPartitionIds() [][]byte

func (*SearchPartitionsRequest) GetQuery

func (x *SearchPartitionsRequest) GetQuery() []float32

func (*SearchPartitionsRequest) ProtoMessage

func (*SearchPartitionsRequest) ProtoMessage()

func (*SearchPartitionsRequest) ProtoReflect

func (x *SearchPartitionsRequest) ProtoReflect() protoreflect.Message

func (*SearchPartitionsRequest) Reset

func (x *SearchPartitionsRequest) Reset()

func (*SearchPartitionsRequest) String

func (x *SearchPartitionsRequest) String() string

type SearchRequest

type SearchRequest struct {
	DatasetId []byte    `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	Query     []float32 `protobuf:"fixed32,2,rep,packed,name=query,proto3" json:"query,omitempty"`
	K         uint32    `protobuf:"varint,3,opt,name=k,proto3" json:"k,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchRequest) Descriptor deprecated

func (*SearchRequest) Descriptor() ([]byte, []int)

Deprecated: Use SearchRequest.ProtoReflect.Descriptor instead.

func (*SearchRequest) GetDatasetId

func (x *SearchRequest) GetDatasetId() []byte

func (*SearchRequest) GetK

func (x *SearchRequest) GetK() uint32

func (*SearchRequest) GetQuery

func (x *SearchRequest) GetQuery() []float32

func (*SearchRequest) ProtoMessage

func (*SearchRequest) ProtoMessage()

func (*SearchRequest) ProtoReflect

func (x *SearchRequest) ProtoReflect() protoreflect.Message

func (*SearchRequest) Reset

func (x *SearchRequest) Reset()

func (*SearchRequest) String

func (x *SearchRequest) String() string

type SearchResultItem

type SearchResultItem struct {
	Id       []byte            `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	Metadata map[string]string `` /* 157-byte string literal not displayed */
	Score    float32           `protobuf:"fixed32,3,opt,name=score,proto3" json:"score,omitempty"`
	// contains filtered or unexported fields
}

func (*SearchResultItem) Descriptor deprecated

func (*SearchResultItem) Descriptor() ([]byte, []int)

Deprecated: Use SearchResultItem.ProtoReflect.Descriptor instead.

func (*SearchResultItem) GetId

func (x *SearchResultItem) GetId() []byte

func (*SearchResultItem) GetMetadata

func (x *SearchResultItem) GetMetadata() map[string]string

func (*SearchResultItem) GetScore

func (x *SearchResultItem) GetScore() float32

func (*SearchResultItem) ProtoMessage

func (*SearchResultItem) ProtoMessage()

func (*SearchResultItem) ProtoReflect

func (x *SearchResultItem) ProtoReflect() protoreflect.Message

func (*SearchResultItem) Reset

func (x *SearchResultItem) Reset()

func (*SearchResultItem) String

func (x *SearchResultItem) String() string

type SearchServer

type SearchServer interface {
	Search(*SearchRequest, Search_SearchServer) error
	SearchPartitions(*SearchPartitionsRequest, Search_SearchPartitionsServer) error
}

SearchServer is the server API for Search service. All implementations should embed UnimplementedSearchServer for forward compatibility

type Search_SearchClient

type Search_SearchClient interface {
	Recv() (*SearchResultItem, error)
	grpc.ClientStream
}

type Search_SearchPartitionsClient

type Search_SearchPartitionsClient interface {
	Recv() (*SearchResultItem, error)
	grpc.ClientStream
}

type Search_SearchPartitionsServer

type Search_SearchPartitionsServer interface {
	Send(*SearchResultItem) error
	grpc.ServerStream
}

type Search_SearchServer

type Search_SearchServer interface {
	Send(*SearchResultItem) error
	grpc.ServerStream
}

type SharedGroupProposal

type SharedGroupProposal struct {
	ProxyName string `protobuf:"bytes,1,opt,name=proxy_name,json=proxyName,proto3" json:"proxy_name,omitempty"`
	Data      []byte `protobuf:"bytes,2,opt,name=data,proto3" json:"data,omitempty"`
	// contains filtered or unexported fields
}

func (*SharedGroupProposal) Descriptor deprecated

func (*SharedGroupProposal) Descriptor() ([]byte, []int)

Deprecated: Use SharedGroupProposal.ProtoReflect.Descriptor instead.

func (*SharedGroupProposal) GetData

func (x *SharedGroupProposal) GetData() []byte

func (*SharedGroupProposal) GetProxyName

func (x *SharedGroupProposal) GetProxyName() string

func (*SharedGroupProposal) ProtoMessage

func (*SharedGroupProposal) ProtoMessage()

func (*SharedGroupProposal) ProtoReflect

func (x *SharedGroupProposal) ProtoReflect() protoreflect.Message

func (*SharedGroupProposal) Reset

func (x *SharedGroupProposal) Reset()

func (*SharedGroupProposal) String

func (x *SharedGroupProposal) String() string

type SharedGroupSnapshot

type SharedGroupSnapshot struct {
	ProxySnapshots map[string][]byte `` /* 191-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*SharedGroupSnapshot) Descriptor deprecated

func (*SharedGroupSnapshot) Descriptor() ([]byte, []int)

Deprecated: Use SharedGroupSnapshot.ProtoReflect.Descriptor instead.

func (*SharedGroupSnapshot) GetProxySnapshots

func (x *SharedGroupSnapshot) GetProxySnapshots() map[string][]byte

func (*SharedGroupSnapshot) ProtoMessage

func (*SharedGroupSnapshot) ProtoMessage()

func (*SharedGroupSnapshot) ProtoReflect

func (x *SharedGroupSnapshot) ProtoReflect() protoreflect.Message

func (*SharedGroupSnapshot) Reset

func (x *SharedGroupSnapshot) Reset()

func (*SharedGroupSnapshot) String

func (x *SharedGroupSnapshot) String() string

type Space

type Space int32
const (
	Space_Euclidean Space = 0
	Space_Manhattan Space = 1
	Space_Cosine    Space = 2
)

func (Space) Descriptor

func (Space) Descriptor() protoreflect.EnumDescriptor

func (Space) Enum

func (x Space) Enum() *Space

func (Space) EnumDescriptor deprecated

func (Space) EnumDescriptor() ([]byte, []int)

Deprecated: Use Space.Descriptor instead.

func (Space) Number

func (x Space) Number() protoreflect.EnumNumber

func (Space) String

func (x Space) String() string

func (Space) Type

func (Space) Type() protoreflect.EnumType

type UUIDRequest

type UUIDRequest struct {
	Id []byte `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
	// contains filtered or unexported fields
}

func (*UUIDRequest) Descriptor deprecated

func (*UUIDRequest) Descriptor() ([]byte, []int)

Deprecated: Use UUIDRequest.ProtoReflect.Descriptor instead.

func (*UUIDRequest) GetId

func (x *UUIDRequest) GetId() []byte

func (*UUIDRequest) ProtoMessage

func (*UUIDRequest) ProtoMessage()

func (*UUIDRequest) ProtoReflect

func (x *UUIDRequest) ProtoReflect() protoreflect.Message

func (*UUIDRequest) Reset

func (x *UUIDRequest) Reset()

func (*UUIDRequest) String

func (x *UUIDRequest) String() string

type UnimplementedDataManagerServer

type UnimplementedDataManagerServer struct {
}

UnimplementedDataManagerServer should be embedded to have forward compatible implementations.

func (UnimplementedDataManagerServer) BatchInsert

func (UnimplementedDataManagerServer) BatchRemove

func (UnimplementedDataManagerServer) BatchUpdate

func (UnimplementedDataManagerServer) Insert

func (UnimplementedDataManagerServer) PartitionBatchInsert

func (UnimplementedDataManagerServer) PartitionBatchRemove

func (UnimplementedDataManagerServer) PartitionBatchUpdate

func (UnimplementedDataManagerServer) PartitionInfo

func (UnimplementedDataManagerServer) Remove

func (UnimplementedDataManagerServer) Update

type UnimplementedDatasetManagerServer

type UnimplementedDatasetManagerServer struct {
}

UnimplementedDatasetManagerServer should be embedded to have forward compatible implementations.

func (UnimplementedDatasetManagerServer) Create

func (UnimplementedDatasetManagerServer) Delete

func (UnimplementedDatasetManagerServer) Get

func (UnimplementedDatasetManagerServer) GetDatasetSize

func (UnimplementedDatasetManagerServer) List

type UnimplementedNodesManagerServer

type UnimplementedNodesManagerServer struct {
}

UnimplementedNodesManagerServer should be embedded to have forward compatible implementations.

func (UnimplementedNodesManagerServer) AddNode

func (UnimplementedNodesManagerServer) ListNodes

func (UnimplementedNodesManagerServer) LoadInfo

func (UnimplementedNodesManagerServer) RemoveNode

type UnimplementedRaftTransportServer

type UnimplementedRaftTransportServer struct {
}

UnimplementedRaftTransportServer should be embedded to have forward compatible implementations.

func (UnimplementedRaftTransportServer) Receive

type UnimplementedSearchServer

type UnimplementedSearchServer struct {
}

UnimplementedSearchServer should be embedded to have forward compatible implementations.

func (UnimplementedSearchServer) Search

func (UnimplementedSearchServer) SearchPartitions

type UnsafeDataManagerServer

type UnsafeDataManagerServer interface {
	// contains filtered or unexported methods
}

UnsafeDataManagerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DataManagerServer will result in compilation errors.

type UnsafeDatasetManagerServer

type UnsafeDatasetManagerServer interface {
	// contains filtered or unexported methods
}

UnsafeDatasetManagerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DatasetManagerServer will result in compilation errors.

type UnsafeNodesManagerServer

type UnsafeNodesManagerServer interface {
	// contains filtered or unexported methods
}

UnsafeNodesManagerServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to NodesManagerServer will result in compilation errors.

type UnsafeRaftTransportServer

type UnsafeRaftTransportServer interface {
	// contains filtered or unexported methods
}

UnsafeRaftTransportServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to RaftTransportServer will result in compilation errors.

type UnsafeSearchServer

type UnsafeSearchServer interface {
	// contains filtered or unexported methods
}

UnsafeSearchServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to SearchServer will result in compilation errors.

type UpdateRequest

type UpdateRequest struct {
	DatasetId []byte            `protobuf:"bytes,1,opt,name=dataset_id,json=datasetId,proto3" json:"dataset_id,omitempty"`
	Id        []byte            `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	Value     []float32         `protobuf:"fixed32,3,rep,packed,name=value,proto3" json:"value,omitempty"`
	Metadata  map[string]string `` /* 157-byte string literal not displayed */
	// contains filtered or unexported fields
}

func (*UpdateRequest) Descriptor deprecated

func (*UpdateRequest) Descriptor() ([]byte, []int)

Deprecated: Use UpdateRequest.ProtoReflect.Descriptor instead.

func (*UpdateRequest) GetDatasetId

func (x *UpdateRequest) GetDatasetId() []byte

func (*UpdateRequest) GetId

func (x *UpdateRequest) GetId() []byte

func (*UpdateRequest) GetMetadata

func (x *UpdateRequest) GetMetadata() map[string]string

func (*UpdateRequest) GetValue

func (x *UpdateRequest) GetValue() []float32

func (*UpdateRequest) ProtoMessage

func (*UpdateRequest) ProtoMessage()

func (*UpdateRequest) ProtoReflect

func (x *UpdateRequest) ProtoReflect() protoreflect.Message

func (*UpdateRequest) Reset

func (x *UpdateRequest) Reset()

func (*UpdateRequest) String

func (x *UpdateRequest) String() string

Jump to